@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: littler.c 136 2008-01-15 00:13:52Z dirk.eddelbuettel $
+ *  $Id: littler.c 145 2008-08-19 16:47:23Z jeffrey.horner $
  */
 
 #include <getopt.h>
@@ -367,11 +367,9 @@ void littler_InitTempDir()
 	}
 }
 
-/* For stdin processing: if an error condition occurs and getOption("error") == NULL,
- * we go here. 
- */
-void littler_CleanUp(SA_TYPE s, int a, int b){
-	exit(1);
+/* Called via q() or if an error condition occurs and getOption("error") == NULL */
+void littler_CleanUp(SA_TYPE saveact, int status, int runLast){
+	exit(status);
 }
 
 void showHelpAndExit() {
@@ -635,10 +633,10 @@ int main(int argc, char **argv){
 	}
 
 	/* Now determine which R code to evaluate */
-	int exit_val;
+	int exit_val = 0;
 	if (evalstr != NULL) {				
 		/* we have a command line expression to evaluate */
-		membuf_t pb = init_membuf(512);
+		membuf_t pb = init_membuf(1024);
 		exit_val = parse_eval(&pb, evalstr, 1);
 		destroy_membuf(pb);
 	} else if (optind < argc && (strcmp(argv[optind],"-") != 0)) {	
